#

##

##

##

##

###

###

    	assets
    		# treasures
    		# gifts
    		# money
    		# eco
    		# treats
    		# trends

    	summary

    	objectives ranked

    		[ ] determine amount

    			1 0000,0000,0000,0000
    			  0000,0000 0000,0000
    			  0000,0000 0000,0000

    	possibilites

    		[ ] assets are minted later?

    			[ ] how?

    	naming
    		best names ranked

    			eco

    			praise

    			thanks

    			tickets
    			slips
    			gems
    			coins
    			shares

    		possible names

    			equity, fungi